/*
 * Copyright (C) 2021 Anton Romanov - All Rights Reserved
 * You may use, distribute and modify this code, please write to: romanov73@gmail.com.
 *
 */

package ru.ulstu.controller;

import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import ru.ulstu.model.News;
import ru.ulstu.service.NewsService;

import javax.validation.Valid;

@Controller
public class NewsController {
    private final NewsService newsService;

    public NewsController(NewsService newsService) {
        this.newsService = newsService;
    }

    @GetMapping("/editNews/{newsId}")
    public String editNews(@PathVariable(value = "newsId") Integer id, Model model) {
        model.addAttribute("news", (id != null && id != 0) ? newsService.getById(id) : new News());
        return "editNews";
    }

    @GetMapping("/news/{newsId}")
    public String viewNews(@PathVariable(value = "newsId") Integer id, Model model) {
        model.addAttribute("news", id != null ? newsService.getById(id) : new News());
        return "news";
    }

    @PostMapping("saveNews")
    public String saveNews(@Valid @ModelAttribute News news, BindingResult result) {
        if (result.hasErrors()) {
            return "editNews";
        }
        newsService.save(news);

        return "redirect:/";
    }

    @GetMapping("deleteNews/{newsId}")
    public String delete(@PathVariable(value = "newsId") Integer id) {
        newsService.delete(id);
        return "redirect:/";
    }
}
